pub struct Stream<A: BaseTx, E: BaseRx, S: StateMarker> { /* private fields */ }Expand description
Handle to a running worker stream.
Wraps thread join handle, cancel token, health flag, action/event channels, and shared state.
Implementations
Sourceimpl<A: BaseTx, E: BaseRx, S: StateMarker> Stream<A, E, S>
impl<A: BaseTx, E: BaseRx, S: StateMarker> Stream<A, E, S>
Sourcepub fn new(
id: Simple,
handle: JoinHandle<StreamResult<()>>,
health: HealthFlag,
action_tx: A,
event_rx: E,
state: Arc<StateCell<S>>,
cancel: CancelToken,
) -> Self
pub fn new( id: Simple, handle: JoinHandle<StreamResult<()>>, health: HealthFlag, action_tx: A, event_rx: E, state: Arc<StateCell<S>>, cancel: CancelToken, ) -> Self
Construct a new stream handle from parts.
Sourcepub fn token(&self) -> &CancelToken
pub fn token(&self) -> &CancelToken
Cancellation token of the stream.
Sourcepub fn is_healthy(&self) -> bool
pub fn is_healthy(&self) -> bool
Check current health flag.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Check if the cancel token is tripped.
Sourcepub fn stop(self) -> StreamResult<()>
pub fn stop(self) -> StreamResult<()>
Cancel and wait for the thread to end.
Sourcepub fn wait_to_end(self) -> StreamResult<()>
pub fn wait_to_end(self) -> StreamResult<()>
Wait for the thread to end, returning its result.
Sourceimpl<A, E, S> Stream<A, E, S>
impl<A, E, S> Stream<A, E, S>
Sourcepub fn try_send(
&mut self,
action: <A as BaseTx>::EventType,
) -> Result<(), SendError<<A as BaseTx>::EventType>>
pub fn try_send( &mut self, action: <A as BaseTx>::EventType, ) -> Result<(), SendError<<A as BaseTx>::EventType>>
Non-blocking send of an action into the worker.
Sourcepub fn send(
&mut self,
action: <A as BaseTx>::EventType,
timeout: Option<Duration>,
) -> Result<(), SendError<<A as BaseTx>::EventType>>
pub fn send( &mut self, action: <A as BaseTx>::EventType, timeout: Option<Duration>, ) -> Result<(), SendError<<A as BaseTx>::EventType>>
Send an action with optional timeout and cancellation.
Sourcepub fn action_tx_mut(&mut self) -> &mut A
pub fn action_tx_mut(&mut self) -> &mut A
Borrow the action TX half.